import { type BuyWithCryptoStatus } from "@thirdweb-dev/sdk";
type ValidBuyWithCryptoStatus = Exclude<BuyWithCryptoStatus, {
    status: 'NOT_FOUND';
}>;
type SwapTxInfo = {
    transactionHash: string;
    status: ValidBuyWithCryptoStatus["status"];
    subStatus?: ValidBuyWithCryptoStatus["subStatus"];
    source: {
        symbol: string;
        value: string;
        chainId: number;
    };
    destination: {
        symbol: string;
        value: string;
        chainId: number;
    };
};
export type Store<T> = {
    getValue(): T;
    setValue(newValue: T): void;
    subscribe(listener: () => void): () => void;
};
/**
 * Create a reactive value store
 * @param initialValue - The initial value to store
 * @example
 * ```ts
 * const store = createStore(0);
 * ```
 * @returns A store object
 * @internal
 */
export declare function createStore<T>(initialValue: T): Store<T>;
export declare const swapTransactionsStore: Store<SwapTxInfo[]>;
/**
 * @internal
 */
export declare const addPendingSwapTransaction: (clientId: string, txInfo: SwapTxInfo) => void;
export {};
//# sourceMappingURL=pendingSwapTx.d.ts.map