import type { WalletConfig } from "@thirdweb-dev/react-core";
import { XDEFIWallet } from "@thirdweb-dev/wallets";
/**
 * @wallet
 */
export type XdefiWalletConfigOptions = {
    /**
     * If `true`, the wallet will be tagged as "recommended" in ConnectWallet Modal. Default is `false`
     */
    recommended?: boolean;
};
/**
 * A wallet configurator for [XDEFI Wallet](https://www.xdefi.io/) which allows integrating the wallet with React.
 *
 * It returns a [`WalletConfig`](https://portal.thirdweb.com/references/react/v4/WalletConfig) object which can be used to connect the wallet to via [`ConnectWallet`](https://portal.thirdweb.com/react/v4/components/ConnectWallet) component or [`useConnect`](https://portal.thirdweb.com/references/react/v4/useConnect) hook as mentioned in [Connecting Wallets](https://portal.thirdweb.com/react/v4/connecting-wallets) guide
 *
 * @example
 * ```ts
 * xdefiWallet({
 *  recommended: true,
 * })
 * ```
 *
 * @param options -
 * Optional configuration options for the wallet
 *
 * ### recommended (optional)
 * If `true`, the wallet will be tagged as "recommended" in [`ConnectWallet`](https://portal.thirdweb.com/react/v4/components/ConnectWallet) Modal UI. Default is `false`
 *
 * @wallet
 */
export declare const xdefiWallet: (options?: XdefiWalletConfigOptions) => WalletConfig<XDEFIWallet>;
//# sourceMappingURL=xdefiWallet.d.ts.map